'use strict';
const fs = require('fs');
const MemoryFileSystem = require('webpack/lib/MemoryOutputFileSystem');
const NodeWatchFileSystem = require('webpack/lib/node/NodeWatchFileSystem');
const wrapFileSystem_1 = require('./utils/wrapFileSystem');
const counterKey = Symbol.for('counter');
class JsxstyleWebpackPlugin {
  constructor() {
    this.pluginName = 'JsxstyleLoaderPlugin';
    this.nmlPlugin = loaderContext => {
      loaderContext[Symbol.for('jsxstyle-loader')] = this.ctx;
    };
    this.compilationPlugin = compilation => {
      if (compilation.hooks) {
        compilation.hooks.normalModuleLoader.tap(
          this.pluginName,
          this.nmlPlugin
        );
      } else {
        compilation.plugin('normal-module-loader', this.nmlPlugin);
      }
    };
    this.donePlugin = () => {
      if (this.ctx.cacheFile) {
        // write contents of cache object as a newline-separated list of CSS strings
        const cacheString = Object.keys(this.ctx.cacheObject).join('\n') + '\n';
        fs.writeFileSync(this.ctx.cacheFile, cacheString, 'utf8');
      }
    };
    this.memoryFS = new MemoryFileSystem();
    // the default cache object. can be overridden on a per-loader instance basis with the `cacheFile` option.
    this.cacheObject = {
      [counterKey]: 0,
    };
    // context object that gets passed to each loader.
    // available in each loader as this[Symbol.for('jsxstyle-loader')]
    this.ctx = {
      cacheFile: null,
      cacheObject: this.cacheObject,
      fileList: new Set(),
      memoryFS: this.memoryFS,
    };
  }
  apply(compiler) {
    const environmentPlugin = () => {
      // compiler is of type `any` here because Compiler types are incomplete
      const wrappedFS = wrapFileSystem_1.default(
        compiler.inputFileSystem,
        this.memoryFS
      );
      compiler.inputFileSystem = wrappedFS;
      compiler.watchFileSystem = new NodeWatchFileSystem(wrappedFS);
    };
    if (compiler.hooks) {
      // webpack 4+
      compiler.hooks.environment.tap(this.pluginName, environmentPlugin);
      compiler.hooks.compilation.tap(this.pluginName, this.compilationPlugin);
      compiler.hooks.done.tap(this.pluginName, this.donePlugin);
    } else {
      // webpack 1-3
      compiler.plugin('environment', environmentPlugin);
      compiler.plugin('compilation', this.compilationPlugin);
      compiler.plugin('done', this.donePlugin);
    }
  }
}
module.exports = JsxstyleWebpackPlugin;
//# sourceMappingURL=plugin.js.map
